#
# spec file for package python-pythonfinder
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-pythonfinder
Version:        1.3.1
Release:        3.9
Summary:        A tool to locate Python on the system
License:        MIT
URL:            https://github.com/sarugaku/pythonfinder
Source:         https://github.com/sarugaku/pythonfinder/archive/refs/tags/v%{version}.tar.gz#/pythonfinder-%{version}.tar.gz
# PATCH-FIX-UPSTREAM gh#sarugaku/pythonfinder#127
Patch0:         support-packaging-22.patch
BuildRequires:  %{python_module setuptools >= 36.2.2}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-attrs
Requires:       python-cached-property
Requires:       python-click
Requires:       python-packaging >= 22.0
Requires:       python-vistir >= 0.2.5
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module attrs}
BuildRequires:  %{python_module cached-property}
BuildRequires:  %{python_module click}
BuildRequires:  %{python_module crayons}
BuildRequires:  %{python_module packaging >= 22.0}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module vistir >= 0.2.5}
# /SECTION
%python_subpackages

%description
A Python discovery tool to locate Python on the system.

%prep
%autosetup -p1 -n pythonfinder-%{version}
rm -r tasks

sed -i '/addopts/d' setup.cfg

# pep514tools is a Windows only dependency which is loosely coupled
# https://travis-ci.org/jayvdb/pythonfinder/builds/505169805
rm -rf src/pythonfinder/_vendor/pep514tools

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/pyfinder
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Three tests fail with OSError: [Errno 1] Operation not permitted , attempting
# to modify read-only system image files.
%pytest -k 'not (test_python_versions or test_shims_are_kept or test_shims_are_removed)'

%post
%python_install_alternative pyfinder

%postun
%python_uninstall_alternative pyfinder

%files %{python_files}
%doc CHANGELOG.rst README.rst
%license LICENSE.txt
%python_alternative %{_bindir}/pyfinder
%{python_sitelib}/*

%changelog
* Mon Feb  6 2023 Steve Kowalik <steven.kowalik@suse.com>
- Add patch support-packaging-22.patch:
  * Support packaging >= 22.
* Mon Dec 12 2022 pgajdos@suse.com
- python-six is not required
* Tue Oct 25 2022 Matej Cepl <mcepl@suse.com>
- Update to 1.3.1:
  - 1.3.0 (2022-24-08)
  - Fix permissions on WSL
  - Include tests and tests data into the sdist Close
  - Make click optional dependency
  - Remove six
  - Drop Python2 Support
  - 1.2.10 (2022-02-19)
  - Check the permission as well as the existence of path
    when finding Pythons.
  - Fix an error of pythonfinder when PATH contains
    unreadable paths.
  - 1.2.9 (2021-11-08)
  - Fix a bug that the version matcher ignores the version
    when patch number is 0.
  - 1.2.8 (2021-07-27)
  - Ensure the path exists when initializing from the PATH
    env var.
  - 1.2.7 (2021-06-24)
  - 1.2.6 (2021-04-01)
  - Remove the deprecated usage of cmp in attr.
  - Fix a bug that version sort is performed on None objects.
  - 1.2.5 (2020-08-27)
  - Skip invalid entries from Windows registry. Ensure paths
    are normalized with forward slashes.
* Wed Feb 23 2022 Andreas Schneider <asn@cryptomilk.org>
- Disable python2 which doesn't build
* Mon Aug  3 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 1.2.4
  * Filter out the None results of Windows python finder.
  * Unnest the mixed output from ``find_all_python_versions()``.
  * Non-core versions of python will no longer sort ahead of core python versions.
  * Reduced dependencies by removing ``vistir``,, ``crayons`` and intermediate calls.
  * Fixed a bug which could cause python searches to fail when ``pyenv global`` was
    set with repeated identical versions.
* Wed May 20 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Fri Jan 10 2020 Tomáš Chvátal <tchvatal@suse.com>
- Do not skip the python2 build manually but wait for the prjconf
  declearation
* Thu Jan  9 2020 Todd R <toddrme2178@gmail.com>
- Drop python2 due to dropped backports indirect dependency.
* Sat May 25 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.2.1:
  * Added support for subprocess timeouts while discovering python paths. #62
- Merged patch setup-ascii.patch
* Sat Mar 16 2019 Jan Engelhardt <jengelh@inai.de>
- Limit description to openSUSE system.
* Wed Mar 13 2019 John Vandenberg <jayvdb@gmail.com>
- Activated test suite
- Removed unnecessary vendored pep514tools from runtime package
* Thu Mar  7 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v1.2.0
